@@ -4,7 +4,7 @@ from sanic import Request
 from pydantic import ValidationError as PdValidationError, BaseModel as PdModel
 from sanic.exceptions import BadRequest
 
-from web_foundation.app.errors.application.application import ValidationError
+from web_foundation.errors.app.application import ValidationError
 
 
 def validate_dto(dto_cls: Type[PdModel] | None,request: Request) -> PdModel | None:
